@@ -19,6 +19,25 @@ from sentry.utils.db import resolve_expression_node
 logger = logging.getLogger(__name__)
 
 
+def merge_account(from_user, to_user):
+    # TODO: we could discover relations automatically and make this useful
+    from sentry.models import GroupBookmark, Project, ProjectKey, Team, TeamMember, \
+      UserOption
+
+    for obj in ProjectKey.objects.filter(user=from_user):
+        obj.update(user=to_user)
+    for obj in TeamMember.objects.filter(user=from_user):
+        obj.update(user=to_user)
+    for obj in Project.objects.filter(owner=from_user):
+        obj.update(owner=to_user)
+    for obj in Team.objects.filter(owner=from_user):
+        obj.update(owner=to_user)
+    for obj in GroupBookmark.objects.filter(user=from_user):
+        obj.update(user=to_user)
+    for obj in UserOption.objects.filter(user=from_user):
+        obj.update(user=to_user)
+
+
 def update(self, using=None, **kwargs):
     """
     Updates specified attributes on the current instance.
