@@ -1,6 +1,6 @@
 """
-sentry.web.frontend.generic
-~~~~~~~~~~~~~~~~~~~~~~~~~~~
+sentry.web.frontend.admin
+~~~~~~~~~~~~~~~~~~~~~~~~~
 
 :copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
